@@ -1,8 +1,7 @@
-import numpy as np
 import subprocess
 import logging
 import os
-import uproot4 as uproot
+import uproot
 import sys
 from astropy.io import fits
 from ogadf_schema.irfs import AEFF_2D, EDISP_2D, PSF_TABLE, BKG_2D, RAD_MAX
@@ -15,7 +14,7 @@ from astropy.table import QTable
 IRF_FILE = "DESY.d20180113.V3.ID0NIM2LST4MST4SST4SCMST4.prod3b-paranal20degs05b-NN.S.3HB9-FD.180000s.root"
 
 
-@pytest.mark.integration
+@pytest.mark.needs_data
 def test_eventdisplay_example(caplog):
     """Runs the EventDisplay example script and check its output."""
 
@@ -51,4 +50,4 @@ def test_eventdisplay_example(caplog):
 
     # TODO shrink margin when we get closer to prevent a regression
     assert ratio.max() < 1.4
-    assert ratio.min() > 0.65
+    assert ratio.min() > 0.60
